SYMBOL adc_data=b0                                  	'hold 10 bit adc value
SYMBOL last_pressure=b1                             	'last recorded pressure
SYMBOL last_temperature=b2                      	'last recorded temperature
SYMBOL min_mbars=b3                            	 	'cutdown pressure altitude
SYMBOL timer=b4                                         'mission elapsed time
SYMBOL stratosphere=b5                             	'in stratosphere? 0=no1=yes
SYMBOL max_time=b6                                 	'maximum flight time
SYMBOL wait_time=b7                                  	'delay to start mission
							'b8 a general use variable

'******************** Set these Variables ***************************
min_mbars = 10                              		'pressure alt to cutdown
max_time = 100                                          'maximum length of mission
wait_time = 1                                           'wait before starting flight
'******************** Set these Variables ***************************
Start_Program:
  	min_mbars = min_mbars / 5			'convert max pressure
  	min_mbars = min_mbars + 26           		'altitude to adc value

Waiting:
IF PIN3 = 0 THEN Waiting				'wait for pin to be pulled

Download_Data:
	FOR b8 = 0 TO 7
    		READ b8,b0                           	'get each byte of data
    		SERTXD (#b0,13,10)            		'download each byte
  	NEXT                 				'for 7 bytes of data

Start_Mission:
  	READADC 1,adc_data                		'get initial temperature
  	last_temperature = adc_data            		'set last temperature
  	WRITE 1,adc_data                         	'store initial temperature
  	READADC 2,adc_data                    		'get initial pressure
  	last_pressure = adc_data                 	'set last pressure
  	WRITE 0,adc_data                          	'store initial pressure

 	FOR b8 = 1 to wait_time
    		PAUSE 60000                   		'wait before start mission
  	NEXT

Ascent:                                                 'check status
  	PAUSE 58000                                     'once every 58s - makes a one minute loop 
  	timer = timer + 1                             	'increment time of flight
  	IF timer = max_time THEN Terminate 	        'if at time limit, then terminate

  	READADC 2,adc_data                   		'get pressure
  	IF adc_data < min_mbars THEN Terminate		'if press limit, terminate
  	b8 = last_pressure + 2                       	'pad last pressure
  	IF adc_data > b8 THEN Terminate  		if descending, terminate
  	IF adc_data >= last_pressure THEN Check_Temperature
							record if pressure decreasing    
  	last_pressure = adc_data                 	'set new lowest pressure

Check_Temperature:
  	READADC 1,adc_data                      	'get temperature
  	IF stratosphere = 1 THEN In_Stratosphere	was in stratosphere?

In_Troposphere:                               		'still in troposphere
  	IF adc_data < last_temperature THEN Done_Checking_Temp
							'getting colder, so done
  	stratosphere = 1                                'must be in stratosphere
  	WRITE 2,timer                                  	'record time to tropopause
  	WRITE 3,last_pressure                      	'record tropopause pressure 
  	WRITE 4,last_temperature                	'record tropopause temp
  	GOTO Done_Checking_Temp

In_Stratosphere:                                         'in stratosphere
  	b8 = last_temperature - 5      			'pad last temperature
  	IF adc_data < b8 THEN terminate			if getting colder terminate

Done_Checking_Temp:
  	last_temperature = adc_data     		save last temp reading
  	GOTO Ascent                                 	loop back

Terminate:
  	WRITE 5,timer                    		'record cutdown time
  	WRITE 6,last_pressure                      	'record cutdown pressure
  	WRITE 7,last_temperature                	'record cutdown temperature
	HIGH 4                                          'turn on burner
  	PAUSE 10000                            		'wait 10 seconds to get hot
  	LOW 4                                           'turn off burner
END
